==> Perl-Examples-0.095.tar.gz: Perl-Examples-0.095/lib/Perl/Examples/POD/Text.pm <==
package Perl::Examples::POD::Text;

1;
# ABSTRACT: Show the various examples of text

__END__

=pod

=encoding UTF-8

=head1 NAME

Perl::Examples::POD::Text - Show the various examples of text

=head1 VERSION

This document describes version 0.095 of Perl::Examples::POD::Text (from Perl distribution Perl-Examples), released on 2020-03-07.

=head1 DESCRIPTION

This is a normal paragraph under Description. This is a normal paragraph under
Description. This is a normal paragraph under Description. This is a normal
paragraph under Description. Mention a module: Pod::Simple. Mention a module and
linkify it: L<Pod::Simple::Text>. I<This is an italicized text>. B<This is an
emphasized text>. C<< This is a code text >>.

This is the second paragraph.

 This is verbatim text. Mention a module: Pod::Simple::Progress. Mention a
 module and linkify it: L<Pod::Simple::PullParser>.

=for comment This is a text under comment.

=for comment This is a data paragraph. Mention a module: Pod::Simple::RTF. Mention a module
and linkify it: L<Pod::Simple::Search>.

=head2 Heading 2

A bullet point list:

=over

=item * Mention a module: Pod::Simple::DebugAsText

=item * Mention a module and linkify it: L<Pod::Simple::DebugAsXML>

=item * Point three

This is text under a bullet point. Mention a module: Pod::Simple::HTML. Mention
a module and linkify it: L<Pod::Simple::HTMLBatch>.

=back

=head2 Heading 2 mentions a module: Pod::Simple::Debug

=head2 Heading 2 mentions a module and linkify it: L<Pod::Simple::BlackBox>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Perl-Examples>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Perl-Examples>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perl-Examples>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020, 2018, 2016, 2015 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

==> Perl-Examples-0.096.tar.gz: Perl-Examples-0.096/lib/Perl/Examples/POD/Text.pm <==
package Perl::Examples::POD::Text;

use strict;

our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
our $DATE = '2023-02-24'; # DATE
our $DIST = 'Perl-Examples'; # DIST
our $VERSION = '0.096'; # VERSION

1;
# ABSTRACT: Show the various examples of text

__END__

=pod

=encoding UTF-8

=head1 NAME

Perl::Examples::POD::Text - Show the various examples of text

=head1 VERSION

This document describes version 0.096 of Perl::Examples::POD::Text (from Perl distribution Perl-Examples), released on 2023-02-24.

=head1 DESCRIPTION

This is a normal paragraph under Description. This is a normal paragraph under
Description. This is a normal paragraph under Description. This is a normal
paragraph under Description. Mention a module: Pod::Simple. Mention a module and
linkify it: L<Pod::Simple::Text>. I<This is an italicized text>. B<This is an
emphasized text>. C<< This is a code text >>.

This is the second paragraph.

 This is verbatim text. Mention a module: Pod::Simple::Progress. Mention a
 module and linkify it: L<Pod::Simple::PullParser>.

=for comment This is a text under comment.

=for comment This is a data paragraph. Mention a module: Pod::Simple::RTF. Mention a module
and linkify it: L<Pod::Simple::Search>.

=head2 Heading 2

A bullet point list:

=over

=item * Mention a module: Pod::Simple::DebugAsText

=item * Mention a module and linkify it: L<Pod::Simple::DebugAsXML>

=item * Point three

This is text under a bullet point. Mention a module: Pod::Simple::HTML. Mention
a module and linkify it: L<Pod::Simple::HTMLBatch>.

=back

=head2 Heading 2 mentions a module: Pod::Simple::Debug

=head2 Heading 2 mentions a module and linkify it: L<Pod::Simple::BlackBox>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Perl-Examples>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Perl-Examples>.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 CONTRIBUTING


To contribute, you can send patches by email/via RT, or send pull requests on
GitHub.

Most of the time, you don't need to build the distribution yourself. You can
simply modify the code, then test via:

 % prove -l

If you want to build the distribution (e.g. to try to install it locally on your
system), you can install L<Dist::Zilla>,
L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
that are considered a bug and can be reported to me.

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2023, 2020, 2018, 2016, 2015 by perlancar <perlancar@cpan.org>.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perl-Examples>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=cut
